import { createEffect, Show, type Accessor, type Component } from "solid-js";
import type { sendImage } from "../../network";
import { useSearchImageContext } from "../../contexts/SearchImageContext";

type ImageStatusProps = {
    processingImage: Accessor<
        Awaited<ReturnType<typeof sendImage>> | undefined
    >;
};

type EventData = "in-progress" | "complete";

export const ImageStatus: Component<ImageStatusProps> = (props) => {
    const { onRefetchImages } = useSearchImageContext();

    const onEvent = (e: MessageEvent<EventData>) => {
        console.log(e.data);

        if (e.data !== "complete") {
            return;
        }

        onRefetchImages();
    };

    createEffect(() => {
        const image = props.processingImage();
        if (image == null) {
            return;
        }

        const eventSource = new EventSource(
            `http://192.168.1.199:3040/image-events/${image.ID}`,
        );

        eventSource.addEventListener("data", onEvent);

        return () => {
            eventSource.removeEventListener("data", onEvent);
        };
    });

    return (
        <Show when={props.processingImage()}>
            {(image) => (
                <div>
                    <p>
                        {image().ImageID} - {image().Status}
                    </p>
                </div>
            )}
        </Show>
    );
};
